==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/BehaviorRuleSettingsVelocity.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BehaviorRuleSettingsVelocity
 */
@JsonPropertyOrder({ BehaviorRuleSettingsVelocity.JSON_PROPERTY_VELOCITY_KPH })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BehaviorRuleSettingsVelocity implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VELOCITY_KPH = "velocityKph";
    private Integer velocityKph = 805;

    public BehaviorRuleSettingsVelocity() {
    }

    public BehaviorRuleSettingsVelocity velocityKph(Integer velocityKph) {

        this.velocityKph = velocityKph;
        return this;
    }

    /**
     * Get velocityKph minimum: 1
     *
     * @return velocityKph
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_VELOCITY_KPH)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public Integer getVelocityKph() {
        return velocityKph;
    }

    @JsonProperty(JSON_PROPERTY_VELOCITY_KPH)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setVelocityKph(Integer velocityKph) {
        this.velocityKph = velocityKph;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BehaviorRuleSettingsVelocity behaviorRuleSettingsVelocity = (BehaviorRuleSettingsVelocity) o;
        return Objects.equals(this.velocityKph, behaviorRuleSettingsVelocity.velocityKph);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(velocityKph);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BehaviorRuleSettingsVelocity {\n");
        sb.append("    velocityKph: ").append(toIndentedString(velocityKph)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/BehaviorRuleSettingsVelocity.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BehaviorRuleSettingsVelocity
 */
@JsonPropertyOrder({ BehaviorRuleSettingsVelocity.JSON_PROPERTY_VELOCITY_KPH })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BehaviorRuleSettingsVelocity implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VELOCITY_KPH = "velocityKph";
    private Integer velocityKph = 805;

    public BehaviorRuleSettingsVelocity() {
    }

    public BehaviorRuleSettingsVelocity velocityKph(Integer velocityKph) {

        this.velocityKph = velocityKph;
        return this;
    }

    /**
     * Get velocityKph minimum: 1
     *
     * @return velocityKph
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_VELOCITY_KPH)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public Integer getVelocityKph() {
        return velocityKph;
    }

    @JsonProperty(JSON_PROPERTY_VELOCITY_KPH)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setVelocityKph(Integer velocityKph) {
        this.velocityKph = velocityKph;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BehaviorRuleSettingsVelocity behaviorRuleSettingsVelocity = (BehaviorRuleSettingsVelocity) o;
        return Objects.equals(this.velocityKph, behaviorRuleSettingsVelocity.velocityKph);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(velocityKph);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BehaviorRuleSettingsVelocity {\n");
        sb.append("    velocityKph: ").append(toIndentedString(velocityKph)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
